%global debug_package %{nil}
%define pkgname       epix
%define libname       %mklibname %{pkgname}
%define devname       %mklibname -d %{pkgname}
%define staticdevname %mklibname -d -s %{pkgname}

Name:    %{pkgname}
Summary: Utilities for creating mathematically accurate figures
Version: 1.2.22
Release: %mkrel 7
License: GPLv2+
Group:   Publishing
URL:     https://mathcs.holycross.edu/~ahwang/current/ePiX.html
Source0: https://mathcs.holycross.edu/~ahwang/%{name}/%{name}-%{version}.tar.gz
Patch1:  0001-Use-ps2eps-as-default-Postscript-to-EPS-converter.patch
Patch2:  0002-Fix-support-for-imagemagick-animated-figures.patch
Patch3:  0003-Fix-help-page-for-webp-support.patch
# add support for apng animations
Patch4:  0004-Add-support-for-APNG-animations.patch
Patch5:  0005-Add-support-for-apng-animations-using-alternative-ap.patch
Patch6:  0006-better-support-for-undocumented-quiet-option.patch
# add parallel support
Patch7:  0007-check-if-a-command-is-available-in-the-executable-pa.patch
Patch8:  0008-Add-parallel-option-to-process-files-in-parallel.patch
#
BuildRequires: automake
BuildRequires: emacs
BuildRequires: gcc-c++
BuildRequires: gzip
BuildRequires: ghostscript
BuildRequires: libtool
BuildRequires: texinfo
BuildRequires: texlive-texmf
Requires: %{devname} = %{version}-%{release}
# ePiX needs the static library to work
Requires: %{staticdevname} = %{version}-%{release}
Requires: apngasm
Requires: gcc-c++
Requires: ghostscript
Requires: imagemagick
Requires: parallel
Requires: texlive-texmf

%description
ePiX (pronounced like "epic" with a soft "k", playing on "TeX") is a
collection of batch programs to create mathematically accurate
figures, plots, and movies using easy-to-learn syntax. The output
(vector image files or LaTeX picture-like environments) is expressly
designed for use with LaTeX.


%package -n %{devname}
Summary: Header files for %{name}

%description -n %{devname}
Development files for %{name}.


%package -n %{staticdevname}
Summary: Static library of %{name}
%description -n %{staticdevname}
This package provides a static library required for %{name}.


%package bash-completion
Summary: Bash completion support for %{name}
BuildArch: noarch
Requires: bash-completion
Requires: %{name} = %{version}-%{release}

%description bash-completion
Bash completion support for the %{name} utilities.

%package -n emacs-%{name}
Summary: Compiled elisp files to run %{name} under GNU Emacs
BuildArch: noarch
Requires: emacs

%description -n emacs-%{name}
This package contains the byte compiled elisp packages to run %{name}
with GNU Emacs.


%prep
%autosetup -p1 -n %{name}-%{version}
# UTF-8 validating and timestamps preserving
for f in THANKS ChangeLog; do
 iconv -f iso8859-1 -t utf8 $f > $f.new && \
 touch -r $f $f.new && \
 mv $f.new $f
done
# Try to fix the Configure WARNING: 'missing' script is too old or missing
autoreconf -fiv

%build
%configure --enable-epix-el \
           --with-ps2eps=%{_bindir}/ps2eps
%make_build

%install
%make_install

gzip -df %{buildroot}%{_datadir}/doc/%{name}/manual.*.gz

# Install bash completion file
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d
cp -p %{buildroot}%{_docdir}/%{name}/config/bash_completions \
      %{buildroot}%{_sysconfdir}/bash_completion.d/%{name}
rm -f %{buildroot}%{_docdir}/%{name}/config/bash_completions

# Install emacs plugin
mkdir -p %{buildroot}%{_emacs_sitelispdir}/%{name} \
         %{buildroot}%{_emacs_sitestartdir}
cp -p %{buildroot}%{_docdir}/%{name}/config/%{name}.el \
      %{buildroot}%{_emacs_sitestartdir}
rm -f %{buildroot}%{_docdir}/%{name}/config/%{name}.el
rmdir %{buildroot}%{_docdir}/%{name}/config

# This directory is not needed anymore since the files it contains were already included with %%doc
rm -rf %{buildroot}%{_docdir}/%{name}/notes

%files
%doc AUTHORS BUGS ChangeLog NEWS POST-INSTALL README THANKS VERSION
%docdir %{_docdir}/%{name}
%license COPYING
%{_bindir}/elaps
%{_bindir}/epix
%{_bindir}/flix
%{_bindir}/laps
%{_infodir}/%{name}.*
%{_mandir}/man1/epix.1*
%{_mandir}/man1/elaps.1*
%{_mandir}/man1/laps.1*
%{_mandir}/man1/flix.1*
%{_datadir}/%{name}
%{_docdir}/%{name}/*

%files -n %{devname}
%license COPYING
%{_includedir}/%{name}
%{_includedir}/*.h

%files -n %{staticdevname}
%license COPYING
%{_libdir}/%{name}

%files bash-completion
%doc README POST-INSTALL
%license COPYING
%config(noreplace) %{_sysconfdir}/bash_completion.d/%{name}

%files -n emacs-%{name}
%doc README POST-INSTALL
%license COPYING
%{_emacs_sitelispdir}/%{name}
%{_emacs_sitestartdir}/*.el



%changelog
* Tue May 24 2022 ghibo <ghibo> 1.2.22-7.mga9
+ Revision: 1860018
- Add support for apng animations through apngasm.
- Add option for parallel processing.

* Tue May 10 2022 ghibo <ghibo> 1.2.22-1.mga9
+ Revision: 1857444
- Update to version 1.2.22.
- Remove patches merged upstream.
- Add patch to use ps2eps as default PS-to-EPS converter.
- Add patch to fix support for animations in flix.
- Add patch to add support for .webp animations in flix.

* Sat May 07 2022 ghibo <ghibo> 1.2.21-1.mga9
+ Revision: 1856604
- imported package epix


* Sat May 07 2022 ghibo <ghibo> - 1.2.21-1.mga9
- initial release based on FC.
- Merge patches for getting package working.
